@@ -1,12 +1,13 @@
 use std::collections::{HashMap, HashSet};
 use std::string::ToString;
-use v_module::remote_indv_r_storage::get_individual;
-use v_module::v_api::app::ResultCode;
-use v_module::v_api::{APIClient, IndvOp, ALL_MODULES};
-use v_module::v_onto::individual::Individual;
-use v_module::v_onto::onto::Onto;
-use v_module::v_onto::parser::parse_raw;
-use v_module::veda_backend::indv_apply_cmd;
+
+use v_common::module::remote_indv_r_storage::get_individual;
+use v_common::module::veda_backend::indv_apply_cmd;
+use v_common::onto::individual::Individual;
+use v_common::onto::onto::Onto;
+use v_common::onto::parser::parse_raw;
+use v_common::v_api::api_client::{APIClient, IndvOp, ALL_MODULES};
+use v_common::v_api::obj::ResultCode;
 
 pub struct CallbackSharedData {
     pub g_key2indv: HashMap<String, Individual>,
